/*
    *
    * This file is a part of CoreAction.
    * A side bar for showing widgets for C Suite.
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/


#include <QFileInfo>
#include <QDir>

#include <cprime/themefunc.h>
#include <cprime/filefunc.h>

#include "settings.h"

settings::settings()
{
	defaultSett = CPrime::Variables::CC_System_ConfigDir() + "coreapps/coreapps.conf";

    // set some default settings that are user specific
    if ( !QFileInfo::exists( defaultSett ) ) {
        cSetting = new QSettings("coreapps", "coreapps");
        qDebug() << "Settings file " << cSetting->fileName();

		CPrime::FileUtils::setupFolder(CPrime::FolderSetup::ConfigFolder);

        setDefaultSettings();
    } else {
        cSetting = new QSettings(defaultSett, QSettings::NativeFormat);
    }
}

settings::~settings()
{
	delete cSetting;
}

void settings::setDefaultSettings()
{
	QString pluginPath = QDir(QStringLiteral(PREFIX_PATH)).filePath("lib/coreapps/plugins");
    cSetting->setValue("CoreApps/KeepActivities", true);
    cSetting->setValue("CoreApps/EnableExperimental", false);
    cSetting->setValue("CoreApps/AutoDetect", true);

    if (autoUIMode() == 2) {
        cSetting->setValue("CoreApps/IconViewIconSize", QSize(56, 56));
        cSetting->setValue("CoreApps/ListViewIconSize", QSize(48, 48));
        cSetting->setValue("CoreApps/ToolsIconSize", QSize(48, 48));
    } else {
        cSetting->setValue("CoreApps/IconViewIconSize", QSize(48, 48));
        cSetting->setValue("CoreApps/ListViewIconSize", QSize(32, 32));
        cSetting->setValue("CoreApps/ToolsIconSize", QSize(24, 24));
    }
	
	cSetting->setValue("CoreAction/PluginsFolders", { pluginPath });
	cSetting->setValue("CoreAction/SelectedPlugins",
					   QStringList() << (pluginPath + "/libsystem.so")
									 << (pluginPath + "/libnetwork.so")
									 << (pluginPath + "/libbatery.so")
									 << (pluginPath + "/libcalendar.so"));

	cSetting->sync();
}

int settings::autoUIMode() const
{
    int formFactor = CPrime::ThemeFunc::getFormFactor();
    int touchMode = CPrime::ThemeFunc::getTouchMode();

    if (formFactor == 2) {
        return 2; // Mobile
    } else if (formFactor == 1 && touchMode == 1) {
        return 1; // Tablet
    } else {
        return 0; // Desktop
    }
}

settings::cProxy settings::getValue(const QString &appName, const QString &key,
                                    const QVariant &defaultValue)
{
    if (appName == "CoreApps" && key == "UIMode") { // Wants to get CoreApps/UIMode
        // Check whether CoreApps/AutoDetect is On
        bool isAutoDetect = cSetting->value("CoreApps/AutoDetect").toBool();

        if (isAutoDetect)
            return cProxy { cSetting, "Dummy", autoUIMode() };
    }

    return cProxy{ cSetting, appName + "/" + key, defaultValue };
}

QString settings::defaultSettingsFilePath() const
{
    return cSetting->fileName();
}
